@@ -22,7 +22,6 @@
 #include <KLocalizedString>
 
 #include "historymanager.h"
-#include "mathengine.h"
 #include "inputmanager.h"
 #include "unitmodel.h"
 #include "version.h"
@@ -82,6 +81,6 @@ int main(int argc, char *argv[])
 
     // required for X11
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.kalk")));
-    KNumber::setDefaultFloatPrecision(1000);
+
     return app.exec();
 }
